"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var dgeni_1 = require("dgeni");
var mockPackage = require('../../mocks/mockPackage');
var path = require('canonical-path');
describe('Host', function () {
    var basePath = path.resolve(__dirname, '../../mocks/tsParser');
    var host;
    var parser;
    /**
     * Creates the Host instance through Dgeni dependency injection. Also allows passing a function
     * that will run in Dgeni's configuration lifecycle and allows modifying the host factory.
     */
    function setupTestDgeniInstance(configureFn) {
        var testPackage = mockPackage();
        testPackage.config(function (tsHost) { return configureFn(tsHost); });
        var dgeni = new dgeni_1.Dgeni([testPackage]);
        var injector = dgeni.configureInjector();
        // Load factories from the Dgeni injector.
        host = injector.get('tsHost');
        parser = injector.get('tsParser');
    }
    it("should read content of a declaration", function () {
        setupTestDgeniInstance(function (h) { return h.concatMultipleLeadingComments = true; });
        var parseInfo = parser.parse(['multipleLeadingComments.ts'], basePath);
        var module = parseInfo.moduleSymbols[0];
        var declaration = module.exportArray[0].valueDeclaration;
        expect(host.getContent(declaration))
            .toEqual('Not a license comment.\nThis is a test function');
    });
    it('should be able to disable leading comment concatenation', function () {
        setupTestDgeniInstance(function (h) { return h.concatMultipleLeadingComments = false; });
        var parseInfo = parser.parse(['multipleLeadingComments.ts'], basePath);
        var module = parseInfo.moduleSymbols[0];
        var declaration = module.exportArray[0].valueDeclaration;
        expect(host.getContent(declaration)).toEqual('This is a test function');
    });
});
//# sourceMappingURL=host.spec.js.map